==> nextcloud-app-spreed-1%3A9.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/vi.js <==
OC.L10N.register(
    "spreed",
    {
    "a conversation" : "Một đàm thoại",
    "(Duration %s)" : "(Thời lượng %s)",
    "You attended a call with {user1}" : "Bạn đã tham dự một cuộc gọi với {user1}",
    "_%n guest_::_%n guests_" : ["%n khách"],
    "You attended a call with {user1} and {user2}" : "Bạn đã tham dự một cuộc gọi với {user1} và {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Bạn đã tham dự một cuộc gọi với {user1}, {user2} và {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Bạn đã tham dự một cuộc gọi với {user1}, {user2}, {user3} và {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Bạn đã tham dự một cuộc gọi với {user1}, {user2}, {user3}, {user4} và {user5}",
    "_%n other_::_%n others_" : ["%n khác"],
    "{actor} invited you to {call}" : "{actor} mời bạn tham dự {call}",
    "Talk" : "Trò chuyện",
    "Guest" : "Khách",
    "{actor} created the conversation" : "{actor} đã tạo đàm thoại",
    "You created the conversation" : "Bạn đã tạo đàm thoại",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} đã đổi tên cuộc hội thoại từ \"%1$s\" thành \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Bạn đã đổi tên cuộc hội thoại từ \"%1$s\" thành \"%2$s\"",
    "{actor} started a call" : "{actor} đã thực hiện một cuộc gọi",
    "You started a call" : "Bạn đã thực hiện một cuộc gọi",
    "{actor} joined the call" : "{actor} đã tham gia cuộc gọi",
    "You joined the call" : "Bạn đã tham gia cuộc gọi",
    "{actor} left the call" : "{actor} đã rời khỏi cuộc gọi",
    "You left the call" : "Bạn đã rời khỏi cuộc gọi",
    "{actor} allowed guests" : "{actor} đã cho phép khách mời",
    "You allowed guests" : "Bạn đã cho phép khách mời",
    "{actor} disallowed guests" : "{actor} đã không cho phép khách mời",
    "You disallowed guests" : "Bạn đã không cho phép khách mời",
    "{actor} set a password" : "{actor} đã đặt mật khẩu",
    "You set a password" : "Bạn đã đặt một mật khẩu",
    "{actor} removed the password" : "{actor} đã xóa mật khẩu",
    "You removed the password" : "Bạn đã xóa mật khẩu",
    "{actor} added {user}" : "{actor} đã thêm {user}",
    "You added {user}" : "Bạn đã thêm {user}",
    "{actor} added you" : "{actor} đã thêm bạn vào",
    "{actor} left the conversation" : "{actor} đã rời khỏi cuộc hội thoại",
    "{actor} removed {user}" : "{actor} đã mời {user} ra ngoài",
    "You removed {user}" : "Bạn đã mời {user} ra ngoài. ",
    "{actor} removed you" : "{actor} đã mời bạn ra ngoài.",
    "{actor} promoted {user} to moderator" : "{actor} đã giới thiệu {user} thành người kiểm duyệt",
    "You promoted {user} to moderator" : "Bạn đã bầu chọn {user} là người kiểm duyệt",
    "{actor} promoted you to moderator" : "{actor} đã bầu chọn cho bạn là người kiểm duyệt",
    "{actor} demoted {user} from moderator" : "{actor} phản đối {user} là người kiểm duyệt",
    "You demoted {user} from moderator" : "Bạn đã phản đối {user} là người kiểm duyệt",
    "{actor} demoted you from moderator" : "{actor} đã phản đối bạn là người kiểm duyệt",
    "{actor} shared a file which is no longer available" : "{actor} đã chia sẻ một tệp không còn tồn tại",
    "You shared a file which is no longer available" : "Bạn đã chia sẻ một tệp không còn tồn tại",
    "%s (guest)" : "%s (khách mời)",
    "Call with {user1} and {user2} (Duration {duration})" : "Đã gọi với {user1} và {user2} (Thời lượng {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Đã gọi với {user1}, {user2} và {user3} (Thời lượng {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Đã gọi với {user1}, {user2}, {user3} và {user4} (Thời lượng {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Đã gọi với {user1}, {user2}, {user3}, {user4} và {user5} (Thời lượng {duration})",
    "Talk to %s" : "Trò chuyện với %s",
    "{user} sent you a private message" : "{user} đã gửi cho bạn một tin nhắn riêng",
    "{user} mentioned you in a private conversation" : "{user} đã đề cập đến bạn trong cuộc trò chuyện riêng",
    "{user} invited you to a private conversation" : "{user} đã mời bạn tham gia cuộc trò chuyện riêng",
    "Join call" : "Tham gia cuộc gọi",
    "{user} invited you to a group conversation: {call}" : "{user} đã mời bạn tham gia cuộc trò chuyện nhóm: {call}",
    "{user} wants to talk with you" : "{user} muốn nói chuyện với bạn",
    "A group call has started in {call}" : "Một cuộc gọi nhóm đã được thực hiện trong {call}",
    "Open settings" : "Mở thiết đặt",
    "Conversations" : "Đàm thoại",
    "Invalid date, date format must be YYYY-MM-DD" : "Định dạng ngày không hợp lệ phải là YYYY-MM-DD",
    "Conversation not found" : "Không tìm thấy cuộc hội thoại",
    "Path is already shared with this room" : "Đường dẫn đã được chia sẻ với phòng này",
    "Leave call" : "Rời khỏi cuộc gọi",
    "Request password" : "Yêu cầu mật khẩu",
    "Error requesting the password." : "Lỗi khi đang yêu cầu mật khẩu.",
    "This conversation has ended" : "Cuộc trò chuyện này đã kết thúc",
    "Limit to groups" : "Giới hạn nhóm",
    "Everyone" : "Tất cả mọi người",
    "Save changes" : "Lưu thay đổi",
    "None" : "Không có",
    "User" : "Người dùng",
    "Disabled" : "Tắt",
    "Users" : "Người dùng",
    "Name" : "Tên",
    "Language" : "Ngôn ngữ",
    "Country" : "Quốc gia",
    "Status" : "Trạng thái",
    "Created at" : "Được tạo ra vào lúc",
    "Pending" : "Đang dừng",
    "Error" : "Lỗi",
    "Blocked" : "Bị chặn",
    "Signaling server URL" : "URL máy chủ đăng ký",
    "Validate SSL certificate" : "Xác thực chứng chỉ SSL",
    "Saved" : "Đã lưu",
    "Shared secret" : "Chia sẽ mật khẩu",
    "STUN server URL" : "URL máy chủ STUN",
    "STUN servers" : "Máy chủ STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Máy chủ STUN được sử dụng để xác định địa chỉ IP công khai của người tham gia phía sau bộ định tuyến.",
    "TURN server URL" : "URL máy chủ TURN",
    "TURN server protocols" : "Giao thức máy chủ TURN",
    "UDP and TCP" : "UDP và TCP",
    "UDP only" : "Chỉ UDP",
    "TCP only" : "Chỉ TCP",
    "Copy link" : "Sao chép liên kết",
    "Waiting for others to join the call …" : "Đang chờ người khác tham gia cuộc gọi…",
    "You can invite others in the participant tab of the sidebar" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên hoặc chia sẻ liên kết này để mời những người khác!",
    "Share this link to invite others!" : "Chia sẻ liên kết này để mời những người khác!",
    "Show your screen" : "Hiện màn hình của bạn",
    "Stop screensharing" : "Ngừng chia sẽ màn hình",
    "Dismiss" : "Bỏ qua",
    "No audio" : "Không có âm thanh",
    "Mute audio (m)" : "Tắt âm thành (m)",
    "Unmute audio (m)" : "Mở âm thanh (m)",
    "Mute audio" : "Tắt âm thanh",
    "Disable video (v)" : "Tắt Video (v)",
    "Enable video (v)" : "Bật Video (v)",
    "Disable video" : "Tắt Video",
    "Enable video" : "Bật Video",
    "Screensharing options" : "Tùy chọn chia sẻ màn hình",
    "Enable screensharing" : "Bật chia sẽ màn hình",
    "Screensharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang phải tải qua HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Chia sẻ màn hình của bạn chỉ hoạt động với Firefox phiên bản 52 trở lên.",
    "Screensharing extension is required to share your screen." : "Cần có tiện ích mở rộng để chia sẻ màn hình của bạn.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome để chia sẻ màn hình của bạn.",
    "An error occurred while starting screensharing." : "Đã xảy ra lỗi khi bắt đầu chia sẻ màn hình.",
    "You" : "Bạn",
    "Show screen" : "Hiện màn hình",
    "Favorite" : "Ưa thích",
    "Leave conversation" : "Rời khỏi cuộc đàm thoại",
    "Delete conversation" : "Xóa đàm thoại",
    "Remove from favorites" : "Xóa khỏi ưa thích",
    "Add to favorites" : "Thêm vào ưa thích",
    "Loading" : "Đang tải",
    "Groups" : "Nhóm",
    "Circles" : "Vòng kết nối",
    "Password protect" : "Mật khẩu bảo vệ",
    "Back" : "Quay lại",
    "Close" : "Đóng",
    "Conversation name" : "Tên đàm thoại",
    "Reply" : "Trả l",
    "Today" : "Hôm nay",
    "Yesterday" : "Hôm qua",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Send message" : "Gửi thông điệp",
    "File to share" : "Tệp để chia sẻ",
    "moderator" : "Người kiểm duyệt",
    "Demote from moderator" : "Hạ uy tín từ người kiểm duyệt",
    "Promote to moderator" : "Giới thiệu người kiểm duyệt",
    "Remove participant" : "Xóa người tham gia",
    "No results" : "Không có kết quả",
    "Add users or groups" : "Add users or groups",
    "Participants" : "Người tham gia",
    "Chat" : "Trò chuyện",
    "Projects" : "Dự án",
    "Settings" : "Thiết lập",
    "Edit" : "Chỉnh sửa",
    "Start call" : "Bắt đầu cuộc gọi",
    "Rename conversation" : "Đổi tên cuộc đàm thoại",
    "Share link" : "Chia sẽ liên kết",
    "Password protection" : "Password protection",
    "Enter a password" : "Nhập mật khẩu",
    "Exit fullscreen (f)" : "Thoát chế độ toàn màn hình (f)",
    "Fullscreen (f)" : "Toàn màn hình (f)",
    "Grid view" : "Xem dạng Lưới",
    "Join a conversation or start a new one" : "Tham gia cuộc trò chuyện hoặc bắt đầu một cuộc trò chuyện mới",
    "Access to microphone & camera is only possible with HTTPS" : "Chỉ có thể truy cập micrô và máy ảnh bằng HTTPS",
    "Please move your setup to HTTPS" : "Vui lòng di chuyển thiết lập của bạn sang HTTPS",
    "Access to microphone & camera was denied" : "Quyền truy cập vào micrô và máy ảnh đã bị từ chối",
    "WebRTC is not supported in your browser" : "WebRTC không được hỗ trợ trong trình duyệt của bạn",
    "Please use a different browser like Firefox or Chrome" : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome",
    "Error while accessing microphone & camera" : "Lỗi khi truy cập micrô và máy ảnh",
    "The password is wrong. Try again." : "Sai mật khẩu. Thử lại.",
    "Password" : "Mật khẩu",
    "TURN server" : "Máy chủ TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Máy chủ TURN được sử dụng để ủy quyền lưu lượng truy cập từ những người tham gia đằng sau tường lửa.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Một máy chủ báo hiệu bên ngoài có thể được sử dụng tùy chọn cho các cài đặt lớn hơn. Để trống để sử dụng máy chủ báo hiệu nội bộ.",
    "%s Talk on your mobile devices" : "%sNói chuyện trên thiết bị di động của bạn ",
    "Android app" : "Ứng dụng Android",
    "iOS app" : "Ứng dụng IOS",
    "{name} (public)" : "{name} (public)",
    "New conversation …" : "Đàm thoại mới...",
    "Copy" : "Sao chép",
    "Copied!" : "Đã sao chép!",
    "Not supported!" : "Không hỗ trợ!",
    "Press ⌘-C to copy." : "Bấm ⌘-C để sao chép.",
    "Press Ctrl-C to copy." : "Bấm Ctrl-C để sao chép.",
    "Please enter the password for this call" : "Hãy nhập một mật khẩu cho cuộc gọi này",
    "Password required" : "Mật khẩu đã được yêu cầu",
    "Cancel" : "Hủy bỏ",
    "Submit" : "Gửi đi",
    "Change password" : "Đổi mật khẩu",
    "Set password" : "Đặt mật khẩu",
    "Rename" : "Đổi tên",
    "Link copied!" : "Liên kết đã được sao chép!",
    "Conversation with {name}" : "Đàm thoại với {name}",
    "Error occurred while setting password" : "Đã xảy ra lỗi khi đặt mật khẩu",
    "No messages yet, start the conversation!" : "Chưa có tin nhắn, bắt đầu cuộc trò chuyện!",
    "New message …" : "Thông điệp mới...",
    "Send" : "Gửi",
    "Share" : "Chia sẻ",
    "[Unknown user name]" : "[Tên người dùng chưa biết]",
    "Error occurred while sending message" : "Đã xảy ra lỗi khi gửi tin nhắn",
    "Error while sharing" : "Lỗi khi chia sẻ",
    "No other people in this call" : "Không có người nào trong cuộc gọi này",
    "Waiting for {participantName} to join the call …" : "Đang chờ {participantName} tham gia cuộc gọi…",
    "WebRTC is not supported in your browser :-/" : "WebRTC không được hỗ trợ trong trình duyệt của bạn :-/",
    "Waiting for camera and microphone permissions" : "Đang chờ cấp quyền đối với máy ảnh và micrô",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Vui lòng cung cấp cho trình duyệt quyền truy cập của bạn để sử dụng máy ảnh và micrô của bạn để sử dụng ứng dụng này.",
    "Set your name in the chat window so other participants can identify you better." : "Đặt tên của bạn trong cửa sổ trò chuyện để những người tham gia khác có thể xác định bạn tốt hơn.",
    "Share screen" : "Chia sẽ màn hình",
    "No Camera" : "Không có Camera",
    "Screensharing is not supported by your browser." : "Chia sẽ màn hình không được hỗ trợ bởi trình duyệt của bạn.",
    "Add participant …" : "Thêm người tham gia …",
    "Favorited" : "Được ưa thích",
    "Your screen" : "Màn hình của bạn",
    "{participantName}'s screen" : "Màn hình của {participantName}",
    "Guest's screen" : "Màn hình Khách",
    "Join conversations at any time, any where, on any device." : "Tham gia cuộc trò chuyện bất kỳ lúc nào, ở bất kỳ đâu, trên mọi thiết bị.",
    "Contacts" : "Liên hệ"
},
"nplurals=1; plural=0;");

==> nextcloud-app-spreed-1%3A10.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/vi.js <==
OC.L10N.register(
    "spreed",
    {
    "a conversation" : "Một đàm thoại",
    "(Duration %s)" : "(Thời lượng %s)",
    "You attended a call with {user1}" : "Bạn đã tham dự một cuộc gọi với {user1}",
    "_%n guest_::_%n guests_" : ["%n khách"],
    "You attended a call with {user1} and {user2}" : "Bạn đã tham dự một cuộc gọi với {user1} và {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Bạn đã tham dự một cuộc gọi với {user1}, {user2} và {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Bạn đã tham dự một cuộc gọi với {user1}, {user2}, {user3} và {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Bạn đã tham dự một cuộc gọi với {user1}, {user2}, {user3}, {user4} và {user5}",
    "_%n other_::_%n others_" : ["%n khác"],
    "{actor} invited you to {call}" : "{actor} mời bạn tham dự {call}",
    "Talk" : "Trò chuyện",
    "Guest" : "Khách",
    "{actor} created the conversation" : "{actor} đã tạo đàm thoại",
    "You created the conversation" : "Bạn đã tạo đàm thoại",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} đã đổi tên cuộc hội thoại từ \"%1$s\" thành \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Bạn đã đổi tên cuộc hội thoại từ \"%1$s\" thành \"%2$s\"",
    "{actor} started a call" : "{actor} đã thực hiện một cuộc gọi",
    "You started a call" : "Bạn đã thực hiện một cuộc gọi",
    "{actor} joined the call" : "{actor} đã tham gia cuộc gọi",
    "You joined the call" : "Bạn đã tham gia cuộc gọi",
    "{actor} left the call" : "{actor} đã rời khỏi cuộc gọi",
    "You left the call" : "Bạn đã rời khỏi cuộc gọi",
    "{actor} allowed guests" : "{actor} đã cho phép khách mời",
    "You allowed guests" : "Bạn đã cho phép khách mời",
    "{actor} disallowed guests" : "{actor} đã không cho phép khách mời",
    "You disallowed guests" : "Bạn đã không cho phép khách mời",
    "{actor} set a password" : "{actor} đã đặt mật khẩu",
    "You set a password" : "Bạn đã đặt một mật khẩu",
    "{actor} removed the password" : "{actor} đã xóa mật khẩu",
    "You removed the password" : "Bạn đã xóa mật khẩu",
    "{actor} added {user}" : "{actor} đã thêm {user}",
    "You added {user}" : "Bạn đã thêm {user}",
    "{actor} added you" : "{actor} đã thêm bạn vào",
    "{actor} left the conversation" : "{actor} đã rời khỏi cuộc hội thoại",
    "{actor} removed {user}" : "{actor} đã mời {user} ra ngoài",
    "You removed {user}" : "Bạn đã mời {user} ra ngoài. ",
    "{actor} removed you" : "{actor} đã mời bạn ra ngoài.",
    "{actor} promoted {user} to moderator" : "{actor} đã giới thiệu {user} thành người kiểm duyệt",
    "You promoted {user} to moderator" : "Bạn đã bầu chọn {user} là người kiểm duyệt",
    "{actor} promoted you to moderator" : "{actor} đã bầu chọn cho bạn là người kiểm duyệt",
    "{actor} demoted {user} from moderator" : "{actor} phản đối {user} là người kiểm duyệt",
    "You demoted {user} from moderator" : "Bạn đã phản đối {user} là người kiểm duyệt",
    "{actor} demoted you from moderator" : "{actor} đã phản đối bạn là người kiểm duyệt",
    "{actor} shared a file which is no longer available" : "{actor} đã chia sẻ một tệp không còn tồn tại",
    "You shared a file which is no longer available" : "Bạn đã chia sẻ một tệp không còn tồn tại",
    "%s (guest)" : "%s (khách mời)",
    "Call with {user1} and {user2} (Duration {duration})" : "Đã gọi với {user1} và {user2} (Thời lượng {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Đã gọi với {user1}, {user2} và {user3} (Thời lượng {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Đã gọi với {user1}, {user2}, {user3} và {user4} (Thời lượng {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Đã gọi với {user1}, {user2}, {user3}, {user4} và {user5} (Thời lượng {duration})",
    "Talk to %s" : "Trò chuyện với %s",
    "{user} sent you a private message" : "{user} đã gửi cho bạn một tin nhắn riêng",
    "{user} mentioned you in a private conversation" : "{user} đã đề cập đến bạn trong cuộc trò chuyện riêng",
    "{user} invited you to a private conversation" : "{user} đã mời bạn tham gia cuộc trò chuyện riêng",
    "Join call" : "Tham gia cuộc gọi",
    "{user} invited you to a group conversation: {call}" : "{user} đã mời bạn tham gia cuộc trò chuyện nhóm: {call}",
    "{user} wants to talk with you" : "{user} muốn nói chuyện với bạn",
    "A group call has started in {call}" : "Một cuộc gọi nhóm đã được thực hiện trong {call}",
    "Open settings" : "Mở thiết đặt",
    "Conversations" : "Đàm thoại",
    "Messages" : "Thông điệp",
    "Invalid date, date format must be YYYY-MM-DD" : "Định dạng ngày không hợp lệ phải là YYYY-MM-DD",
    "Conversation not found" : "Không tìm thấy cuộc hội thoại",
    "Path is already shared with this room" : "Đường dẫn đã được chia sẻ với phòng này",
    "Leave call" : "Rời khỏi cuộc gọi",
    "Request password" : "Yêu cầu mật khẩu",
    "Error requesting the password." : "Lỗi khi đang yêu cầu mật khẩu.",
    "This conversation has ended" : "Cuộc trò chuyện này đã kết thúc",
    "Limit to groups" : "Giới hạn nhóm",
    "Everyone" : "Tất cả mọi người",
    "Save changes" : "Lưu thay đổi",
    "None" : "Không có",
    "User" : "Người dùng",
    "Disabled" : "Tắt",
    "Users" : "Người dùng",
    "Name" : "Tên",
    "Language" : "Ngôn ngữ",
    "Country" : "Quốc gia",
    "Status" : "Trạng thái",
    "Created at" : "Được tạo ra vào lúc",
    "Pending" : "Đang dừng",
    "Error" : "Lỗi",
    "Blocked" : "Bị chặn",
    "Validate SSL certificate" : "Xác thực chứng chỉ SSL",
    "Saved" : "Đã lưu",
    "Shared secret" : "Chia sẽ mật khẩu",
    "STUN server URL" : "URL máy chủ STUN",
    "STUN servers" : "Máy chủ STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Máy chủ STUN được sử dụng để xác định địa chỉ IP công khai của người tham gia phía sau bộ định tuyến.",
    "TURN server URL" : "URL máy chủ TURN",
    "TURN server protocols" : "Giao thức máy chủ TURN",
    "UDP and TCP" : "UDP và TCP",
    "UDP only" : "Chỉ UDP",
    "TCP only" : "Chỉ TCP",
    "Copy link" : "Sao chép liên kết",
    "Waiting for others to join the call …" : "Đang chờ người khác tham gia cuộc gọi…",
    "You can invite others in the participant tab of the sidebar" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên hoặc chia sẻ liên kết này để mời những người khác!",
    "Share this link to invite others!" : "Chia sẻ liên kết này để mời những người khác!",
    "Show your screen" : "Hiện màn hình của bạn",
    "Stop screensharing" : "Ngừng chia sẽ màn hình",
    "Dismiss" : "Bỏ qua",
    "No audio" : "Không có âm thanh",
    "Mute audio (m)" : "Tắt âm thành (m)",
    "Unmute audio (m)" : "Mở âm thanh (m)",
    "Mute audio" : "Tắt âm thanh",
    "Disable video (v)" : "Tắt Video (v)",
    "Enable video (v)" : "Bật Video (v)",
    "Disable video" : "Tắt Video",
    "Enable video" : "Bật Video",
    "Screensharing options" : "Tùy chọn chia sẻ màn hình",
    "Enable screensharing" : "Bật chia sẽ màn hình",
    "Screensharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang phải tải qua HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Chia sẻ màn hình của bạn chỉ hoạt động với Firefox phiên bản 52 trở lên.",
    "Screensharing extension is required to share your screen." : "Cần có tiện ích mở rộng để chia sẻ màn hình của bạn.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome để chia sẻ màn hình của bạn.",
    "An error occurred while starting screensharing." : "Đã xảy ra lỗi khi bắt đầu chia sẻ màn hình.",
    "You" : "Bạn",
    "Show screen" : "Hiện màn hình",
    "Favorite" : "Ưa thích",
    "Leave conversation" : "Rời khỏi cuộc đàm thoại",
    "Delete conversation" : "Xóa đàm thoại",
    "Remove from favorites" : "Xóa khỏi ưa thích",
    "Add to favorites" : "Thêm vào ưa thích",
    "Loading" : "Đang tải",
    "Groups" : "Nhóm",
    "Circles" : "Vòng kết nối",
    "Settings" : "Thiết lập",
    "Password protect" : "Mật khẩu bảo vệ",
    "Back" : "Quay lại",
    "Close" : "Đóng",
    "Conversation name" : "Tên đàm thoại",
    "Reply" : "Trả l",
    "Remove" : "Xóa bỏ",
    "Today" : "Hôm nay",
    "Yesterday" : "Hôm qua",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Send message" : "Gửi thông điệp",
    "File to share" : "Tệp để chia sẻ",
    "Enabled" : "Bật",
    "Save" : "Lưu",
    "Password" : "Mật khẩu",
    "API token" : "Tín chỉ API",
    "Login" : "Login",
    "Nickname" : "Biệt danh",
    "moderator" : "Người kiểm duyệt",
    "Demote from moderator" : "Hạ uy tín từ người kiểm duyệt",
    "Promote to moderator" : "Giới thiệu người kiểm duyệt",
    "Remove participant" : "Xóa người tham gia",
    "No results" : "Không có kết quả",
    "Add users or groups" : "Add users or groups",
    "Participants" : "Người tham gia",
    "Chat" : "Trò chuyện",
    "Edit" : "Chỉnh sửa",
    "Keyboard shortcuts" : "Phím tắt",
    "Search" : "Tìm",
    "Start call" : "Bắt đầu cuộc gọi",
    "Rename conversation" : "Đổi tên cuộc đàm thoại",
    "Share link" : "Chia sẽ liên kết",
    "Password protection" : "Password protection",
    "Enter a password" : "Nhập mật khẩu",
    "Exit fullscreen (f)" : "Thoát chế độ toàn màn hình (f)",
    "Fullscreen (f)" : "Toàn màn hình (f)",
    "Grid view" : "Xem dạng Lưới",
    "Send" : "Gửi",
    "Start a conversation" : "Bắt đầu một cuộc Đàm thoại",
    "Join a conversation or start a new one" : "Tham gia cuộc trò chuyện hoặc bắt đầu một cuộc trò chuyện mới",
    "Default" : "Mặc định",
    "Access to microphone & camera is only possible with HTTPS" : "Chỉ có thể truy cập micrô và máy ảnh bằng HTTPS",
    "Please move your setup to HTTPS" : "Vui lòng di chuyển thiết lập của bạn sang HTTPS",
    "Access to microphone & camera was denied" : "Quyền truy cập vào micrô và máy ảnh đã bị từ chối",
    "WebRTC is not supported in your browser" : "WebRTC không được hỗ trợ trong trình duyệt của bạn",
    "Please use a different browser like Firefox or Chrome" : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome",
    "Error while accessing microphone & camera" : "Lỗi khi truy cập micrô và máy ảnh",
    "The password is wrong. Try again." : "Sai mật khẩu. Thử lại.",
    "TURN server" : "Máy chủ TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Máy chủ TURN được sử dụng để ủy quyền lưu lượng truy cập từ những người tham gia đằng sau tường lửa.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Một máy chủ báo hiệu bên ngoài có thể được sử dụng tùy chọn cho các cài đặt lớn hơn. Để trống để sử dụng máy chủ báo hiệu nội bộ.",
    "%s Talk on your mobile devices" : "%sNói chuyện trên thiết bị di động của bạn ",
    "Android app" : "Ứng dụng Android",
    "iOS app" : "Ứng dụng IOS",
    "No other people in this call" : "Không có người nào trong cuộc gọi này",
    "Your screen" : "Màn hình của bạn",
    "Contacts" : "Liên hệ",
    "[Unknown user name]" : "[Tên người dùng chưa biết]",
    "Projects" : "Dự án",
    "Please enter the password for this call" : "Hãy nhập một mật khẩu cho cuộc gọi này",
    "Password required" : "Mật khẩu đã được yêu cầu",
    "Cancel" : "Hủy bỏ",
    "Submit" : "Gửi đi",
    "Signaling server URL" : "URL máy chủ đăng ký"
},
"nplurals=1; plural=0;");
